
import { WebhookRequest } from "@webuildbots/webuildbots-sdk";
import isDate from "is-date-object";

interface FormValue {
  title: string;
  value: FormValue | any;
}

interface PathValue {
  path: string;
  value: any;
}

type FormValueRoot = Record<string, FormValue>;

export const getPathValuesFromForm = (
  formValue: FormValueRoot,
  user: WebhookRequest["user"],
  storeUserId = false,
): PathValue[] => {
  let array = [];
  for (const formSegment in formValue) {
    const value = formValue[formSegment];
    array = array.concat(getPathValues(value, []));
  }
  if (storeUserId) {
    array.push({path: "session id", value: user._id})
  }
  return array;
};

const isFormValue = (obj) => {
  return (
    obj &&
    Object.keys(obj).length === 2 &&
    Object.keys(obj)[0] === "title" &&
    Object.keys(obj)[1] === "value"
  );
};

export const getPathValues = (
  obj: FormValue | Record<string, any>,
  path: string[] = [],
): PathValue[] => {
  if (!isFormValue(obj)) {
    if (isDate(obj)) {
      return [{path: path.join("."), value: (obj as Date).toDateString()}];
    }
    const isObject = obj && typeof obj === "object";
    if (!isObject) {
      return [{path: path.join("."), value: obj}];
    }
    let pathValues = [];
    for (const key of Object.keys(obj || {})) {
      if (isFormValue(obj[key])) {
        const pathVal = getPathValues(obj[key], path);
        pathValues = pathValues.concat(pathVal);
      } else {
        return [{path: path.join("."), value: obj}];
      }
    }
    return pathValues;
  }
  const newPath = [...path, obj.title] as string[];
  return getPathValues(obj.value, newPath);
};
