/* eslint-disable @typescript-eslint/no-var-requires */
const path = require("path");
const CopyPlugin = require("copy-webpack-plugin");
const ForkTsCheckerWebpackPlugin = require("fork-ts-checker-webpack-plugin");
const nodeExternals = require("webpack-node-externals");

const environment =
  process.env.ENVIRONMENT === "stage" ? "development" : "production";

module.exports = {
  mode: environment,
  entry: "./src/handlers/index.ts",
  resolve: {
    extensions: [".json", ".ts"],
    alias: {
      "@modules": path.resolve(__dirname, "./src/interfaces"),
    },
  },
  devtool: "source-map",
  output: {
    libraryTarget: "commonjs",
    path: path.join(__dirname, ".webpack"),
    filename: "index.js",
  },
  externals: [nodeExternals()],
  target: "node",
  module: {
    rules: [
      {
        test: /\.ts$/,
        loader: "ts-loader",
        options: {transpileOnly: true, configFile: "tsconfig.json"},
      },
    ],
  },
  plugins: [
    // environment === "production" &&
    //   new SentryWebpack({
    //     release: commitHash,
    //     org: "webuildbots",
    //     project: "<<client>>-cloud-functions",
    //     // webpack specific configuration
    //     include: ".webpack",
    //     ignore: ["node_modules", "webpack.config.js"],
    //   }),
    new ForkTsCheckerWebpackPlugin({
      async: true,
      eslint: {
        enabled: true,
        files: "./src/**/*.{ts,tsx}",
      },
    }),
    new CopyPlugin({
      patterns: [{from: path.resolve(__dirname, "package.json")}],
    }),
  ].filter((plugin) => plugin),
};
